<template>
  <div class="card-list" v-change-height:card-list-box>
    <div class="card-list-box">
      <card-group v-for="(card, cardIndex) in cardList" :key="cardIndex">
        <!-- 按钮组 -->
        <template v-slot:content>
          <div class="diy">
            <div class="card-item" v-show="!card.hide">
              <!-- 左边 -->
              <div class="card-item-left">
                <!-- 功能标识 -->
                <div class="card-item-left-main">
                  <!-- 图标 -->
                  <div class="card-item-left-main-icon iconfont" :class="`iconfont-${card.icon.key}`" />
                  <div class="card-item-left-main-text">
                    <!-- 卡片名字 -->
                    <p class="card-item-left-main-text-name" v-text="card.name" />
                    <!-- 卡片描述 -->
                    <p class="card-item-left-main-text-describe" v-text="'根据个人偏好设定'" />
                  </div>
                </div>
              </div>
              <!-- 右边 -->
              <div class="card-item-right">
                <!-- 编辑 -->
                <span class="card-item-right-edit" v-text="'编辑'" />
              </div>
            </div>
            <div class="card-main">
              <div class="card-main-list"></div>
            </div>
          </div>
        </template>
      </card-group>
    </div>
    <popup-group />
  </div>
</template>

<script>
import { Switch } from 'gree-ui';
import { glyphs } from '@assets/iconfont/iconfont.json';
import BtnGroup from '@/components/BtnGroup/index';
import CardGroup from '@/components/CardGroup/index';
import { mapState, mapGetters } from 'vuex';
import PopupGroup from '@/components/Popup/index';
import temUnChange from '@/mixins/tem';

export default {
  name: 'diy-card',
  components: {
    [Switch.name]: Switch,
    [BtnGroup.name]: BtnGroup,
    [CardGroup.name]: CardGroup,
    [PopupGroup.name]: PopupGroup
  },
  data() {
    return {
      jsonMap: {
        1: 'CoolSvStTemMin',
        2: 'HumiSvStTemMin',
        4: 'HeatSvStTemMax',
        6: 'Heat3DSvStTemMax',
        7: 'Heat2SvStTemMax'
      }
    };
  },
  mixins: [temUnChange],
  computed: {
    ...mapState('control', {
      Mod: state => state.dataObject.Mod,
      CoolSvStTemMin: state => state.dataObject.CoolSvStTemMin || 18,
      HumiSvStTemMin: state => state.dataObject.HumiSvStTemMin || 18,
      HeatSvStTemMax: state => state.dataObject.HeatSvStTemMax || 18,
      Heat3DSvStTemMax: state => state.dataObject.Heat3DSvStTemMax || 18,
      Heat2SvStTemMax: state => state.dataObject.Heat2SvStTemMax || 18,
      HumiEnable: state => state.dataObject.HumiEnable,
      TemUn: state => state.dataObject.TemUn
    }),
    ...mapGetters(['cardFuncDefine', 'modTextKey', 'modCurrentStatusName', 'spModCurrentStatusName']),
    ...mapGetters('machine', ['statusMap', 'blindModelArr']),
    cardList() {
      if (!Object.keys(this.statusMap).length) return [];
      const result = this.cardFuncDefine.map(model => {
        const identifier = model.identifier;
        if (!this.statusMap[identifier])
          return {
            icon: {},
            handler: () => {
              console.log('Undefined function');
            }
          };
        // 当前status定义
        const status = this.statusMap[identifier].status;
        // 取名称
        const defaultNameKey = `btn.${identifier}`;
        const footerKey = `footer.${identifier}`;
        const describeKey = `describe.${identifier}`;

        const statusNameText = status.name;
        const stateNameText = `${defaultNameKey}_${statusNameText}`;

        const name = stateNameText === this.$language(stateNameText) ? this.$language(defaultNameKey) : this.$language(stateNameText);
        const footer = this.parseStr(footerKey);
        const describe = this.parseStr(describeKey);
        // 图标
        const icon = glyphs.some(item => item.font_class === status.icon.key) ? status.icon : { key: 'undefined', type: 'off' };
        // 是否隐藏
        const hide = this.blindModelArr.includes(identifier);
        // 执行的方法
        const handler = (identifier, disable = false) => {
          disable || this.$stateMachine.nextStatus(identifier);
        };
        return { key: identifier, name, icon, hide, handler, footer, describe };
      });
      return result.filter(value => {
        return value.key === 'DIY';
      });
    }
  },
  watch: {},
  methods: {
    parseStr(str) {
      //  没想好怎么处理，记得改
      if (str === 'describe.SvSt') {
        const { modText } = this;
        // const jsonMap = {
        //   1: 'CoolSvStTemMin',
        //   2: 'HumiSvStTemMin',
        //   4: 'HeatSvStTemMax',
        //   6: 'Heat3DSvStTemMax',
        //   7: 'Heat2SvStTemMax'
        // };
        return this.$language(modText) + this.svstTextList + this[this.jsonMap[this.Mod]] + this.describeUnit;
      }
      return this.$language(str);
    }
    // showPopup(key) {
    //   this.SetPopup({ [key]: true });
    // }
  }
};
</script>

<style lang="scss">
.card-list {
  position: relative;
  // height: 530px;
  padding-bottom: 40px;
  // width: 100%;
  // background-color: transparent;
  // display: flex;
  // justify-content: center;
  .diy {
    height: 530px;
    width: 100%;
    .card-item {
      // $cardPadding: 30px;
      // height: calc(160px - #{$cardPadding} * 2;
      height: 140px;
      width: 100%;
      display: flex;
      justify-content: space-between;
      align-items: center;
      // padding: $cardPadding 0;
      &-left {
        height: 100%;
        width: 100%;
        display: flex;
        justify-content: space-between;
        align-items: center;
        &-main {
          height: 100%;
          width: 100%;
          margin-left: 20px;
          display: flex;
          justify-content: flex-start;
          align-items: center;
          &-icon {
            $iconHeight: 68px;
            background-image: linear-gradient(180deg, #7fb5f6, #6da4e6);
            height: $iconHeight;
            width: $iconHeight;
            line-height: $iconHeight;
            margin-left: 42px;
            border-radius: 50%;
            font-size: 40px;
            color: #fff;
            text-align: center;
          }
          &-text {
            padding-left: 20px;
            &-name {
              font-size: 48px;
              color: #404657;
              display: inline;
              &:after {
                content: '|';
                color: #989898;
                opacity: 0.2;
                padding-left: 15px;
                padding-right: 15px;
              }
            }
            &-describe {
              color: #989898;
              font-size: 36px;
              display: inline;
            }
            &-footer {
              font-size: 36px;
              color: #989898;
            }
          }
        }
        &::after {
          width: 0px;
        }
      }
      &-right {
        // padding: 0 52px 0 24px;
        width: auto;
        height: 100%;
        display: flex;
        justify-content: flex-start;
        align-items: center;
        &-edit {
          position: absolute;
          right: 58px;
          font-size: 46px;
        }
      }
    }
    .card-main {
      width: 100%;
      height: 390px;
      &-list {
        height: 360px;
        width: calc(100% - 72px);
        margin-left: 36px;
      }
    }
  }
}
</style>
